#ifndef CF_ROOTS_H
#define CF_ROOTS_H

int* Zp_roots (const CanonicalForm f);


#endif
